#!/bin/bash

# This script expects the (full) path of libreadline.a.
# It prints out the (full) path of the (hopefully) corresponding readline.h.

if [ $# -ne 1 ]
then
  echo "$0: requires 1 arg (path of READLINE library)"
  exit 1
fi

READLINE_LIB="$1"

# If READLINE is in std directory, assume header is too.  Output nothing.
if [ "X$READLINE_LIB" = "X-lreadline" ]
then
  exit 0
fi

READLINE_LIB_DIR=`dirname "$READLINE_LIB"`
READLINE_LIB_DIR_DIR=`dirname "$READLINE_LIB_DIR"`
READLINE_HDR_DIR="$READLINE_LIB_DIR_DIR/include/readline"

if [ -f "$READLINE_HDR_DIR/readline.h" -a -r "$READLINE_HDR_DIR/readline.h" ]
then
  # We've found a plausible readline.h.
  echo "$READLINE_HDR_DIR"
  exit 0
fi

echo "Trouble reading READLINE header file $READLINE_HDR_DIR/readline.h"
exit 2
