#!/bin/bash

# This script looks for a READLINE library in a standard location.
# If a single READLINE library is found, it prints out the full path of
# the (static) library and returns with exit code 0.
# If none is found or several are found, it prints out an error message
# and returns with a non-zero exit code.

##################################################################
# Use find to search through various standard directories.
# NB look through all directories, even if a READLINE has already been found.

if [ $# -ne 0 ]
then
  echo "$0 expects no args"
  exit 1
fi

# List of directories under which libgmp.a and/or libgmp.so is normally found.
STD_LIBDIRS="/usr/lib:/usr/lib64:/usr/lib32:/usr/local:/opt/local/lib:/sw/lib:/usr/sfw/lib"
IFS=":"
READLINE_PATHS=readline-paths
/bin/rm -rf $READLINE_PATHS
for directory in $STD_LIBDIRS
do
  if [ -d "$directory" ]
  then
#    if [ -f "$directory/libreadline.a" ];  then echo "$directory/libreadline.a"  >> $READLINE_PATHS; fi
    find "$directory" -name  libreadline.a   -print >> $READLINE_PATHS  2> /dev/null
#    find "$directory" -name  libreadline.so  -print >> $READLINE_PATHS  2> /dev/null
  fi
done

if [ \! -s $READLINE_PATHS ]
then
  # Did not find any plausible READLINE library, so return empty handed.
  /bin/rm -rf $READLINE_PATHS
  echo "Did not find libreadline in $STD_LIBDIRS"
  exit 1
fi

# Slightly odd call to wc is to avoid it printing out the file name.
if [ `wc -l < $READLINE_PATHS` -ne 1 ]
then
  echo "*** Found multiple READLINE libraries ***"
  cat $READLINE_PATHS
  /bin/rm $READLINE_PATHS
  exit 2
fi

# We have found a single file called libreadline.a or libreadline.so;
# do a couple of quick sanity checks before declaring our search successful...
READLINE_LIB=`cat $READLINE_PATHS`
/bin/rm $READLINE_PATHS
if [ -f "$READLINE_LIB" -a -r "$READLINE_LIB" ]
then
#  echo "$READLINE_LIB"
  echo "-lreadline"
  exit 0
else
  echo "Trouble reading READLINE library file $READLINE_LIB"
  exit 4
fi
